@@ -7,12 +7,13 @@ impl<'de> Deserializer<'de> for DeJsValue {
     where
         V: Visitor<'de>,
     {
-        // log::trace!(
-        //     "deserialize_any::<{}>(...) [type: {}; value: {:?}]",
-        //     std::any::type_name::<V>(),
-        //     std::any::type_name::<V::Value>(),
-        //     self.value
-        // );
+        #[cfg(feature = "debug-logs")]
+        log::trace!(
+            "deserialize_any::<{}>(...) [type: {}; value: {:?}]",
+            std::any::type_name::<V>(),
+            std::any::type_name::<V::Value>(),
+            self.value
+        );
 
         self.value
             .deserialize_any(visitor)
